@@ -3,7 +3,7 @@ use MooseX::Role::Parameterized;
 use DBIx::Class::Objects::Attribute::Trait::DBIC;
 use DBIx::Class::Objects::Util 'class_name_to_private_accessor';
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 parameter 'handles' => (
     isa      => 'ArrayRef[Str]',
@@ -36,6 +36,11 @@ role {
         isa      => $param->result_source_class,
         required => 1,
     );
+    has 'object_source' => (
+	is       => 'rw',
+	isa      => 'DBIx::Class::Objects',
+	required => 1,
+    );
 
     # XXX This looks strange, but here's what's going on. Inside of our
     after 'BUILD' => sub {
@@ -65,6 +70,8 @@ C<load_objects> method on C<DBIx::Class::Objects>.
 
 Curtis "Ovid" Poe, C<< <ovid at cpan.org> >>
 
+Dan Burke C<< dburke at addictmud.org >>
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-object-bridge at
